using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Windows.Forms;
using System.Data;
using System.Security;
using Microsoft.Practices.EnterpriseLibrary.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Data.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Security.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Security.Database;
using Microsoft.Practices.EnterpriseLibrary.Security.Database.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Security.Database.Authentication.Configuration;
using EntLibData = Microsoft.Practices.EnterpriseLibrary.Data;
using BookingApp.Helpers;

namespace BookingApp.Admin
{
	public class UserRole : BookingApp.TaskForms.BaseForm
	{
		private System.Windows.Forms.GroupBox gbxUserRoles;
		private System.Windows.Forms.Button btnEditRole;
		private System.Windows.Forms.Button btnRemove;
		private System.Windows.Forms.Button btnAdd;
		private System.Windows.Forms.Button btnDelUser;
		private System.Windows.Forms.Button btnAddNewUser;
		private System.Windows.Forms.Button btnAddNewRole;
		private System.Windows.Forms.Button btnDelRole;
		private System.Windows.Forms.ComboBox cbxRoles;
		private System.Windows.Forms.Label lblRoleUsers;
		private System.Windows.Forms.ListBox lbxRoleUsers;
		private System.Windows.Forms.Label lblRoles;
		private System.Windows.Forms.ListBox lbxUsers;
		private System.Windows.Forms.Label lblUsers;
		private System.ComponentModel.IContainer components = null;

		private ConfigurationContext configurationContext;
		private UserRoleManager userRoleMgr;
		private System.Windows.Forms.Button btnEditUser; 
		private static readonly string paragraphSeparator = System.Environment.NewLine + System.Environment.NewLine;

		public UserRole(ConfigurationContext configurationContext)
		{
			// Test Authorization
			// Rule: [R:SystemAdmin OR R:Manager OR R:Agent]
			if (!SecurityHelper.Authorized(AuthRule.SystemAdmin))
			{
				throw new SecurityException(String.Format("No permition to access system administration task. -- User[{0}]", SecurityHelper.UserCredential.Name));
			}

			// This call is required by the Windows Form Designer.
			InitializeComponent();

			// TODO: Add any initialization after the InitializeComponent call
			this.configurationContext = configurationContext;
			UpdateEditRoleButtonEnabled();
			UpdateEditUserButtonEnabled();
			UpdateConnectButtonEnabled();
			UpdateUserToRoleButtonsEnabled();
			InitForm();
		}

		public UserRole() : this(ConfigurationManager.GetCurrentContext()) {}

		private void InitForm()
		{
			this.gbxUserRoles.Enabled = false;
			string databaseInstance = this.DbAuthenticationProvider.Database;

			try 
			{
				this.Cursor = Cursors.WaitCursor;

				this.userRoleMgr = new UserRoleManager(databaseInstance, ConfigurationManager.GetCurrentContext());

				GetAllUsers();
				GetAllRoles();

				this.gbxUserRoles.Enabled = true;
			} 
			catch(Exception e)
			{
				string msg = SR.NoDatabaseExceptionMessage(paragraphSeparator, paragraphSeparator, paragraphSeparator, e.Message);
				MessageBox.Show(msg, SR.DatabaseConnectionError, MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
			finally 
			{
				this.Cursor = Cursors.Default;
			}
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region ɵĴ
		/// <summary>
		/// ֧ķ - Ҫʹô༭޸
		/// ˷ݡ
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(UserRole));
			this.gbxUserRoles = new System.Windows.Forms.GroupBox();
			this.btnEditRole = new System.Windows.Forms.Button();
			this.btnRemove = new System.Windows.Forms.Button();
			this.btnAdd = new System.Windows.Forms.Button();
			this.btnDelUser = new System.Windows.Forms.Button();
			this.btnAddNewUser = new System.Windows.Forms.Button();
			this.btnAddNewRole = new System.Windows.Forms.Button();
			this.btnDelRole = new System.Windows.Forms.Button();
			this.cbxRoles = new System.Windows.Forms.ComboBox();
			this.lblRoleUsers = new System.Windows.Forms.Label();
			this.lbxRoleUsers = new System.Windows.Forms.ListBox();
			this.lblRoles = new System.Windows.Forms.Label();
			this.lbxUsers = new System.Windows.Forms.ListBox();
			this.lblUsers = new System.Windows.Forms.Label();
			this.btnEditUser = new System.Windows.Forms.Button();
			this.gbxUserRoles.SuspendLayout();
			this.SuspendLayout();
			// 
			// gbxUserRoles
			// 
			this.gbxUserRoles.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.gbxUserRoles.Controls.Add(this.btnEditRole);
			this.gbxUserRoles.Controls.Add(this.btnRemove);
			this.gbxUserRoles.Controls.Add(this.btnAdd);
			this.gbxUserRoles.Controls.Add(this.btnDelUser);
			this.gbxUserRoles.Controls.Add(this.btnAddNewUser);
			this.gbxUserRoles.Controls.Add(this.btnAddNewRole);
			this.gbxUserRoles.Controls.Add(this.btnDelRole);
			this.gbxUserRoles.Controls.Add(this.cbxRoles);
			this.gbxUserRoles.Controls.Add(this.lblRoleUsers);
			this.gbxUserRoles.Controls.Add(this.lbxRoleUsers);
			this.gbxUserRoles.Controls.Add(this.lblRoles);
			this.gbxUserRoles.Controls.Add(this.lbxUsers);
			this.gbxUserRoles.Controls.Add(this.lblUsers);
			this.gbxUserRoles.Controls.Add(this.btnEditUser);
			this.gbxUserRoles.Enabled = false;
			this.gbxUserRoles.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.gbxUserRoles.Location = new System.Drawing.Point(8, 48);
			this.gbxUserRoles.Name = "gbxUserRoles";
			this.gbxUserRoles.Size = new System.Drawing.Size(568, 272);
			this.gbxUserRoles.TabIndex = 16;
			this.gbxUserRoles.TabStop = false;
			// 
			// btnEditRole
			// 
			this.btnEditRole.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnEditRole.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.btnEditRole.Location = new System.Drawing.Point(115, 293);
			this.btnEditRole.Name = "btnEditRole";
			this.btnEditRole.Size = new System.Drawing.Size(87, 25);
			this.btnEditRole.TabIndex = 13;
			this.btnEditRole.Text = "Edit Role";
			// 
			// btnRemove
			// 
			this.btnRemove.Cursor = System.Windows.Forms.Cursors.Default;
			this.btnRemove.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnRemove.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.btnRemove.Location = new System.Drawing.Point(248, 168);
			this.btnRemove.Name = "btnRemove";
			this.btnRemove.Size = new System.Drawing.Size(67, 26);
			this.btnRemove.TabIndex = 7;
			this.btnRemove.Text = "-->>";
			this.btnRemove.Click += new System.EventHandler(this.btnRemove_Click);
			// 
			// btnAdd
			// 
			this.btnAdd.Cursor = System.Windows.Forms.Cursors.Default;
			this.btnAdd.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnAdd.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.btnAdd.Location = new System.Drawing.Point(248, 128);
			this.btnAdd.Name = "btnAdd";
			this.btnAdd.Size = new System.Drawing.Size(67, 26);
			this.btnAdd.TabIndex = 6;
			this.btnAdd.Text = "<<--";
			this.btnAdd.Click += new System.EventHandler(this.btnAdd_Click);
			// 
			// btnDelUser
			// 
			this.btnDelUser.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.btnDelUser.Cursor = System.Windows.Forms.Cursors.Default;
			this.btnDelUser.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnDelUser.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.btnDelUser.Location = new System.Drawing.Point(468, 239);
			this.btnDelUser.Name = "btnDelUser";
			this.btnDelUser.Size = new System.Drawing.Size(87, 26);
			this.btnDelUser.TabIndex = 12;
			this.btnDelUser.Text = "Delete User";
			this.btnDelUser.Click += new System.EventHandler(this.btnDelUser_Click);
			// 
			// btnAddNewUser
			// 
			this.btnAddNewUser.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.btnAddNewUser.Cursor = System.Windows.Forms.Cursors.Default;
			this.btnAddNewUser.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnAddNewUser.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.btnAddNewUser.Location = new System.Drawing.Point(276, 239);
			this.btnAddNewUser.Name = "btnAddNewUser";
			this.btnAddNewUser.Size = new System.Drawing.Size(87, 26);
			this.btnAddNewUser.TabIndex = 11;
			this.btnAddNewUser.Text = "New User";
			this.btnAddNewUser.Click += new System.EventHandler(this.btnAddNewUser_Click);
			// 
			// btnAddNewRole
			// 
			this.btnAddNewRole.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnAddNewRole.Cursor = System.Windows.Forms.Cursors.Default;
			this.btnAddNewRole.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnAddNewRole.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.btnAddNewRole.Location = new System.Drawing.Point(19, 239);
			this.btnAddNewRole.Name = "btnAddNewRole";
			this.btnAddNewRole.Size = new System.Drawing.Size(87, 26);
			this.btnAddNewRole.TabIndex = 9;
			this.btnAddNewRole.Text = "New Role";
			this.btnAddNewRole.Click += new System.EventHandler(this.btnAddNewRole_Click);
			// 
			// btnDelRole
			// 
			this.btnDelRole.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnDelRole.Cursor = System.Windows.Forms.Cursors.Default;
			this.btnDelRole.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnDelRole.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.btnDelRole.Location = new System.Drawing.Point(120, 239);
			this.btnDelRole.Name = "btnDelRole";
			this.btnDelRole.Size = new System.Drawing.Size(87, 26);
			this.btnDelRole.TabIndex = 10;
			this.btnDelRole.Text = "Delete Role";
			this.btnDelRole.Click += new System.EventHandler(this.btnDelRole_Click);
			// 
			// cbxRoles
			// 
			this.cbxRoles.Cursor = System.Windows.Forms.Cursors.Default;
			this.cbxRoles.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.cbxRoles.ItemHeight = 18;
			this.cbxRoles.Location = new System.Drawing.Point(14, 47);
			this.cbxRoles.Name = "cbxRoles";
			this.cbxRoles.Size = new System.Drawing.Size(212, 26);
			this.cbxRoles.TabIndex = 4;
			this.cbxRoles.SelectedIndexChanged += new System.EventHandler(this.cbxRoles_SelectedIndexChanged);
			// 
			// lblRoleUsers
			// 
			this.lblRoleUsers.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.lblRoleUsers.Location = new System.Drawing.Point(10, 87);
			this.lblRoleUsers.Name = "lblRoleUsers";
			this.lblRoleUsers.Size = new System.Drawing.Size(292, 17);
			this.lblRoleUsers.TabIndex = 7;
			this.lblRoleUsers.Text = "Users in Role";
			// 
			// lbxRoleUsers
			// 
			this.lbxRoleUsers.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left)));
			this.lbxRoleUsers.ItemHeight = 18;
			this.lbxRoleUsers.Location = new System.Drawing.Point(14, 121);
			this.lbxRoleUsers.Name = "lbxRoleUsers";
			this.lbxRoleUsers.Size = new System.Drawing.Size(210, 112);
			this.lbxRoleUsers.TabIndex = 5;
			// 
			// lblRoles
			// 
			this.lblRoles.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.lblRoles.Location = new System.Drawing.Point(10, 30);
			this.lblRoles.Name = "lblRoles";
			this.lblRoles.Size = new System.Drawing.Size(96, 17);
			this.lblRoles.TabIndex = 4;
			this.lblRoles.Text = "Roles";
			// 
			// lbxUsers
			// 
			this.lbxUsers.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.lbxUsers.ItemHeight = 18;
			this.lbxUsers.Location = new System.Drawing.Point(336, 119);
			this.lbxUsers.Name = "lbxUsers";
			this.lbxUsers.Size = new System.Drawing.Size(216, 112);
			this.lbxUsers.TabIndex = 8;
			this.lbxUsers.SelectedIndexChanged += new System.EventHandler(this.lbxUsers_SelectedIndexChanged);
			// 
			// lblUsers
			// 
			this.lblUsers.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.lblUsers.Location = new System.Drawing.Point(336, 87);
			this.lblUsers.Name = "lblUsers";
			this.lblUsers.Size = new System.Drawing.Size(115, 17);
			this.lblUsers.TabIndex = 8;
			this.lblUsers.Text = "All Users";
			// 
			// btnEditUser
			// 
			this.btnEditUser.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.btnEditUser.Cursor = System.Windows.Forms.Cursors.Default;
			this.btnEditUser.Enabled = false;
			this.btnEditUser.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnEditUser.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.btnEditUser.Location = new System.Drawing.Point(372, 239);
			this.btnEditUser.Name = "btnEditUser";
			this.btnEditUser.Size = new System.Drawing.Size(87, 26);
			this.btnEditUser.TabIndex = 11;
			this.btnEditUser.Text = "Edit User";
			this.btnEditUser.Click += new System.EventHandler(this.btnEditUser_Click);
			// 
			// UserRole
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(7, 17);
			this.ClientSize = new System.Drawing.Size(592, 376);
			this.Controls.Add(this.gbxUserRoles);
			this.FormTask = "User and Role administration";
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.Name = "UserRole";
			this.Controls.SetChildIndex(this.gbxUserRoles, 0);
			this.gbxUserRoles.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		private void UpdateEditRoleButtonEnabled() 
		{
			btnEditRole.Enabled = cbxRoles.SelectedItem != null;
		}

		private void UpdateUserToRoleButtonsEnabled() 
		{
			btnAdd.Enabled = lbxUsers.SelectedItem != null && cbxRoles.SelectedItem != null && lbxRoleUsers.FindStringExact(lbxUsers.SelectedValue.ToString()) == -1;
			btnRemove.Enabled = lbxRoleUsers.SelectedItem != null;
		}
		private void UpdateEditUserButtonEnabled() 
		{
			btnEditUser.Enabled = lbxUsers.SelectedIndex >= 0;
		}
		private void UpdateConnectButtonEnabled() 
		{
			//selectDbButton.Enabled = cbxDbInstances.SelectedItem != null;
		}

		private void cbxRoles_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			GetUsersInRole(cbxRoles.Text);
			UpdateEditRoleButtonEnabled();
			UpdateUserToRoleButtonsEnabled();		
		}

		private void btnAddNewRole_Click(object sender, System.EventArgs e)
		{
			ShowRoleFormDialog();
			UpdateUserToRoleButtonsEnabled();
		}

		private void btnDelRole_Click(object sender, System.EventArgs e)
		{
			if (cbxRoles.SelectedIndex < 0)
			{
				MessageBox.Show(SR.MustSelectRoleToDelete);
				return;
			}

			MessageBoxButtons buttons = MessageBoxButtons.YesNo;

			if (MessageBox.Show(this, SR.DeleteRoleConfirmation, SR.DeleteRoleConfirmation, buttons) == DialogResult.Yes)
			{
				string role = ((DataRowView)cbxRoles.SelectedItem)["RoleName"].ToString();

				this.userRoleMgr.DeleteRole(role);

				GetAllRoles();
				GetAllUsers();
			}

			GetUsersInRole(cbxRoles.Text);
			UpdateEditRoleButtonEnabled();
			UpdateUserToRoleButtonsEnabled();
		}

		private void btnAdd_Click(object sender, System.EventArgs e)
		{
			AddUserRole();
		}

		private void btnRemove_Click(object sender, System.EventArgs e)
		{
			RemoveUserRole();
		}

		private void btnAddNewUser_Click(object sender, System.EventArgs e)
		{
			ShowUserFormDialog();
		}
		private void ShowUserFormDialog(string username) 
		{
			UserForm userForm;
            
			if (username.Length > 0) 
			{
				userForm = new UserForm(DbAuthenticationProvider, configurationContext, username);
			}
			else 
			{
				userForm = new UserForm(DbAuthenticationProvider, configurationContext);
			}

			if (userForm.ShowDialog(this) == DialogResult.OK)
			{
				GetAllUsers();
			}
		}

		private void ShowUserFormDialog() 
		{
			ShowUserFormDialog(String.Empty);
		}

		private void btnEditUser_Click(object sender, System.EventArgs e)
		{
			ShowUserFormDialog(lbxUsers.SelectedValue.ToString()); 
		}

		private void btnDelUser_Click(object sender, System.EventArgs e)
		{
			if (lbxUsers.SelectedIndex < 0)
			{
				MessageBox.Show(SR.MustSelectUserToDelete);
				return;
			}
			else
			{
				string message = SR.DeleteUserConfirmation;
				string caption = SR.DeleteUserConfirmationCaption;
				MessageBoxButtons buttons = MessageBoxButtons.YesNo;

				if (MessageBox.Show(this, message, caption, buttons) == DialogResult.No)
				{
					return;
				}
			}

			string user = ((DataRowView)lbxUsers.SelectedItem)["UserName"].ToString();

			this.userRoleMgr.DeleteUser(user);

			GetAllUsers();
			GetUsersInRole(cbxRoles.Text);
			UpdateEditUserButtonEnabled();
			UpdateUserToRoleButtonsEnabled();
		}
		private void GetUsersInRole(string role)
		{
			if (role.Trim().Length > 0) 
			{
				DataSet ds = this.userRoleMgr.GetRoleUsers(role.Trim());

				lbxRoleUsers.BeginUpdate();
				lbxRoleUsers.DisplayMember = "UserName";
				lbxRoleUsers.ValueMember = "UserName";
				lbxRoleUsers.DataSource = ds.Tables[0];
				lbxRoleUsers.EndUpdate();

			} 
			else 
			{
				lbxRoleUsers.DataSource = null;
			}

			lblRoleUsers.Text = SR.UsersInRole(role);
		}

		private void GetAllRoles()
		{
			DataSet ds = this.userRoleMgr.GetAllRoles();

			cbxRoles.BeginUpdate();
			cbxRoles.DisplayMember = "RoleName";
			cbxRoles.ValueMember = "RoleName";
			cbxRoles.DataSource = ds.Tables[0];
			cbxRoles.EndUpdate();
		}

		private void GetAllUsers()
		{
			DataSet ds = this.userRoleMgr.GetAllUsers();

			lbxUsers.BeginUpdate();
			lbxUsers.DisplayMember = "UserName";
			lbxUsers.ValueMember = "UserName";
			lbxUsers.DataSource = ds.Tables[0];
			lbxUsers.EndUpdate();
		}
		private void ShowRoleFormDialog() 
		{
			ShowRoleFormDialog(String.Empty);
		}

		private void ShowRoleFormDialog(string role) 
		{
			RoleForm roleForm;
            
			if (role.Length > 0) 
			{
				roleForm = new RoleForm(DbAuthenticationProvider, configurationContext, role);
			} 
			else 
			{
				roleForm = new RoleForm(DbAuthenticationProvider, configurationContext);
			}
            
			if (roleForm.ShowDialog(this) == DialogResult.OK)
			{
				GetAllRoles();

				cbxRoles.SelectedIndex = cbxRoles.FindStringExact(roleForm.RoleName);
				GetUsersInRole(roleForm.RoleName);
			} 
		}
		private void AddUserRole()
		{
			string tmpUser = ((DataRowView)lbxUsers.SelectedItem)["UserName"].ToString();

			this.userRoleMgr.CreateUserRole(tmpUser, cbxRoles.Text);
			GetUsersInRole(cbxRoles.Text);
			UpdateUserToRoleButtonsEnabled();
		}

		private void RemoveUserRole()
		{
			string tmpUser = ((DataRowView)lbxRoleUsers.SelectedItem)["UserName"].ToString();

			this.userRoleMgr.DeleteUserRole(tmpUser, cbxRoles.Text);
			GetUsersInRole(cbxRoles.Text);
			UpdateUserToRoleButtonsEnabled();
		}

		private void lbxUsers_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			UpdateEditUserButtonEnabled();
			UpdateUserToRoleButtonsEnabled();
		}

		public DbAuthenticationProviderData DbAuthenticationProvider 
		{
			get 
			{
				DbAuthenticationProviderData providerData = null;
				//TODO:firestar
				SecuritySettings securitySettings = (SecuritySettings)configurationContext.GetConfiguration(SecuritySettings.SectionName);
				foreach(AuthenticationProviderData instance in securitySettings.AuthenticationProviders) 
				{
				
					if (instance is DbAuthenticationProviderData) 
					{
						providerData = instance as DbAuthenticationProviderData;
						break;
					}
				}

				//DbAuthenticationProviderData providerData = cbxDbInstances.SelectedItem as DbAuthenticationProviderData;
				return providerData;
			}
		}


	}
}

