using System;
using System.Threading;
using System.Windows.Forms;

namespace BookingApp
{
	public class EntryPoint
	{
		private EntryPoint()
		{
		}

        static void Main() 
        {
            Application.ThreadException += 
                new ThreadExceptionEventHandler(Application_ThreadException);
			AppDomain.CurrentDomain.UnhandledException += 
				new System.UnhandledExceptionEventHandler(AppDomain_UnHandledException);

            Application.EnableVisualStyles();
            Application.Run(new MainForm());
        }

		public static void Application_ThreadException(object sender, System.Threading.ThreadExceptionEventArgs e)
		{
			HandleException(e.Exception, ExPolicy.General);
		}

		public static void AppDomain_UnHandledException(object sender, System.UnhandledExceptionEventArgs e)
		{
			if (e.ExceptionObject is System.Exception)
			{
				HandleException((System.Exception)e.ExceptionObject, ExPolicy.Unhandled);
			}
		}

		public static void HandleException(Exception ex, string policy)
		{
			Boolean rethrow = false;
			try
			{
				rethrow = Microsoft.Practices.EnterpriseLibrary.ExceptionHandling.ExceptionPolicy.HandleException(ex, policy);
			}
			catch (Exception innerEx)
			{
				string errorMsg = "An unexpected exception occured while calling HandleException with policy '" + policy + "'. ";
				errorMsg += Environment.NewLine + innerEx.ToString();
				MessageBox.Show(errorMsg, "Application Error", MessageBoxButtons.OK, MessageBoxIcon.Stop);
				throw ex;
			}
			if (rethrow)
			{
				throw ex; // WARNING: This will truncate the stack of the exception
			}
			else
			{
				MessageBox.Show("An unhandled exception occurred and has been logged. Please contact support.");
				Application.Exit();
			}
		}
	}
}
