using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Windows.Forms;
using System.Security;

using Microsoft.Practices.EnterpriseLibrary.Caching;
using Microsoft.Practices.EnterpriseLibrary.Caching.Expirations;
using Microsoft.Practices.EnterpriseLibrary.Logging;
using Microsoft.Practices.EnterpriseLibrary.Security;
using Microsoft.Practices.EnterpriseLibrary.Security.Database;
using Microsoft.Practices.EnterpriseLibrary.Security.Cache.CachingStore;
using Microsoft.Practices.EnterpriseLibrary.Security.Authorization;
using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling;
using BookingApp.BLL;
using BookingApp.Helpers;

namespace BookingApp.TaskForms
{
	public class Booking : BookingApp.TaskForms.BaseForm
	{
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.Label timestampLabel;
		private System.Windows.Forms.TextBox quoteTextBox;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.DateTimePicker flightDatePicker;
		private System.Windows.Forms.ComboBox arriveCityCombo;
		private System.Windows.Forms.ComboBox departCityCombo;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label6;
		private System.ComponentModel.IContainer components = null;
		private System.Windows.Forms.Button btnBooking;
		private System.Windows.Forms.Button btnDiscount;
		private System.Windows.Forms.Button btnGetQuote;

		private IList _cities = null;
		private IList _pre_Cities = null;

		public Booking()
		{
			// Test Authorization
			// Rule: [R:SystemAdmin OR R:Manager OR R:Agent]
			if (!SecurityHelper.Authorized(AuthRule.GetQuote))
			{
				throw new SecurityException(String.Format("No permition to access booking task. -- User[{0}]", SecurityHelper.UserCredential.Name));
			}

			// This call is required by the Windows Form Designer.
			InitializeComponent();

			// TODO: Add any initialization after the InitializeComponent call
			_cities = GetCities();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region ɵĴ
		/// <summary>
		/// ֧ķ - Ҫʹô༭޸
		/// ˷ݡ
		/// </summary>
		private void InitializeComponent()
		{
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.btnBooking = new System.Windows.Forms.Button();
			this.label5 = new System.Windows.Forms.Label();
			this.timestampLabel = new System.Windows.Forms.Label();
			this.btnDiscount = new System.Windows.Forms.Button();
			this.btnGetQuote = new System.Windows.Forms.Button();
			this.quoteTextBox = new System.Windows.Forms.TextBox();
			this.label4 = new System.Windows.Forms.Label();
			this.flightDatePicker = new System.Windows.Forms.DateTimePicker();
			this.arriveCityCombo = new System.Windows.Forms.ComboBox();
			this.departCityCombo = new System.Windows.Forms.ComboBox();
			this.label3 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.label6 = new System.Windows.Forms.Label();
			this.groupBox1.SuspendLayout();
			this.SuspendLayout();
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.btnBooking);
			this.groupBox1.Controls.Add(this.label5);
			this.groupBox1.Controls.Add(this.timestampLabel);
			this.groupBox1.Controls.Add(this.btnDiscount);
			this.groupBox1.Controls.Add(this.btnGetQuote);
			this.groupBox1.Controls.Add(this.quoteTextBox);
			this.groupBox1.Controls.Add(this.label4);
			this.groupBox1.Controls.Add(this.flightDatePicker);
			this.groupBox1.Controls.Add(this.arriveCityCombo);
			this.groupBox1.Controls.Add(this.departCityCombo);
			this.groupBox1.Controls.Add(this.label3);
			this.groupBox1.Controls.Add(this.label2);
			this.groupBox1.Controls.Add(this.label6);
			this.groupBox1.Location = new System.Drawing.Point(8, 56);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(568, 264);
			this.groupBox1.TabIndex = 2;
			this.groupBox1.TabStop = false;
			// 
			// btnBooking
			// 
			this.btnBooking.Enabled = false;
			this.btnBooking.Location = new System.Drawing.Point(256, 224);
			this.btnBooking.Name = "btnBooking";
			this.btnBooking.Size = new System.Drawing.Size(90, 25);
			this.btnBooking.TabIndex = 25;
			this.btnBooking.Text = "Booking";
			this.btnBooking.Visible = false;
			this.btnBooking.Click += new System.EventHandler(this.btnBooking_Click);
			// 
			// label5
			// 
			this.label5.Location = new System.Drawing.Point(16, 176);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(144, 25);
			this.label5.TabIndex = 24;
			this.label5.Text = "Cities Last Loaded:";
			// 
			// timestampLabel
			// 
			this.timestampLabel.Location = new System.Drawing.Point(168, 176);
			this.timestampLabel.Name = "timestampLabel";
			this.timestampLabel.Size = new System.Drawing.Size(211, 25);
			this.timestampLabel.TabIndex = 23;
			// 
			// btnDiscount
			// 
			this.btnDiscount.Enabled = false;
			this.btnDiscount.Location = new System.Drawing.Point(472, 224);
			this.btnDiscount.Name = "btnDiscount";
			this.btnDiscount.Size = new System.Drawing.Size(80, 25);
			this.btnDiscount.TabIndex = 22;
			this.btnDiscount.Text = "Discount";
			this.btnDiscount.Visible = false;
			this.btnDiscount.Click += new System.EventHandler(this.btnDiscount_Click);
			// 
			// btnGetQuote
			// 
			this.btnGetQuote.Location = new System.Drawing.Point(144, 224);
			this.btnGetQuote.Name = "btnGetQuote";
			this.btnGetQuote.Size = new System.Drawing.Size(90, 25);
			this.btnGetQuote.TabIndex = 21;
			this.btnGetQuote.Text = "Get Quote";
			this.btnGetQuote.Click += new System.EventHandler(this.btnGetQuote_Click);
			// 
			// quoteTextBox
			// 
			this.quoteTextBox.Location = new System.Drawing.Point(152, 136);
			this.quoteTextBox.Name = "quoteTextBox";
			this.quoteTextBox.ReadOnly = true;
			this.quoteTextBox.Size = new System.Drawing.Size(120, 24);
			this.quoteTextBox.TabIndex = 20;
			this.quoteTextBox.Text = "";
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(24, 136);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(57, 25);
			this.label4.TabIndex = 19;
			this.label4.Text = "Quote:";
			// 
			// flightDatePicker
			// 
			this.flightDatePicker.Location = new System.Drawing.Point(152, 102);
			this.flightDatePicker.Name = "flightDatePicker";
			this.flightDatePicker.Size = new System.Drawing.Size(240, 24);
			this.flightDatePicker.TabIndex = 18;
			// 
			// arriveCityCombo
			// 
			this.arriveCityCombo.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.arriveCityCombo.Location = new System.Drawing.Point(152, 59);
			this.arriveCityCombo.Name = "arriveCityCombo";
			this.arriveCityCombo.Size = new System.Drawing.Size(146, 26);
			this.arriveCityCombo.Sorted = true;
			this.arriveCityCombo.TabIndex = 17;
			// 
			// departCityCombo
			// 
			this.departCityCombo.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.departCityCombo.Location = new System.Drawing.Point(152, 25);
			this.departCityCombo.Name = "departCityCombo";
			this.departCityCombo.Size = new System.Drawing.Size(146, 26);
			this.departCityCombo.Sorted = true;
			this.departCityCombo.TabIndex = 16;
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(24, 63);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(120, 25);
			this.label3.TabIndex = 15;
			this.label3.Text = "Arrival City:";
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(24, 102);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(120, 25);
			this.label2.TabIndex = 14;
			this.label2.Text = "Travel Date:";
			// 
			// label6
			// 
			this.label6.Location = new System.Drawing.Point(24, 25);
			this.label6.Name = "label6";
			this.label6.Size = new System.Drawing.Size(120, 24);
			this.label6.TabIndex = 13;
			this.label6.Text = "Departure City:";
			// 
			// Booking
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(7, 17);
			this.ClientSize = new System.Drawing.Size(592, 376);
			this.Controls.Add(this.groupBox1);
			this.FormTask = "Booking ticket ...";
			this.Name = "Booking";
			this.Load += new System.EventHandler(this.Booking_Load);
			this.Controls.SetChildIndex(this.groupBox1, 0);
			this.groupBox1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// Get's a list of cities.  Uses Enterprise Library Caching block to cache the city list.
		/// Also demonstrates the logging block when a cache miss occurs.
		/// </summary>
		/// <returns></returns>
		private IList GetCities() 
		{
			IList cities = null;
			DateTime timestamp;
			Pricing pricing = new Pricing();
			CacheManager cache = CacheFactory.GetCacheManager();
			cities = cache.GetData("cities") as IList;
			if (cities == null) 
			{
				// Write a log message that we didn't get a cache hit
				Logger.Write("Booking app refreshing cities list from pricing service");
				timestamp = DateTime.MinValue;
				try 
				{
					// get it from the web service
					cities = pricing.GetCities();

					// add it to the cache
					// This commented-out version uses the SlidingTime expiration of 15 seconds.
					// Every time the value is requested, its expiration is postponed by 15 seconds.
					// ICacheItemExpiration expiration = new Expirations.SlidingTime(new TimeSpan(0, 0, 0, 15));
					// The implemented version uses an Absolute Time expiration so that the value will time out
					// in 15 seconds no matter how many times it is requested.
					ICacheItemExpiration expiration = new AbsoluteTime(new TimeSpan(0, 0, 0, 10));
					cache.Add("cities", cities, CacheItemPriority.Normal, null, expiration);
					timestamp = DateTime.Now;
					cache.Add("timestamp", timestamp, CacheItemPriority.Normal, null, expiration);
				} 
				catch (Exception ex) 
				{
					bool rethrow = ExceptionPolicy.HandleException(ex, "General Policy");
					if (rethrow) 
					{
						throw ex;
					}
				}
				
			}
			else 
			{
				timestamp = (DateTime)cache.GetData("timestamp");
			}
			timestampLabel.Text = timestamp.ToString();
			return cities;
		}

		private void btnGetQuote_Click(object sender, System.EventArgs e)
		{
			this.Message = "";
			try 
			{
				Pricing pricing = new Pricing();
				decimal price = pricing.GetPrice(departCityCombo.Text, arriveCityCombo.Text, flightDatePicker.Value);
				quoteTextBox.Text = price.ToString("c");

				btnBooking.Enabled = true;
				btnDiscount.Enabled = true;
			}
			catch 
			{
				MessageBox.Show("No flights available");
			}
		}

		private void Booking_Load(object sender, System.EventArgs e)
		{
			this.Message = "";

			// If cities is null at this point, we had an error - close the form
			if (null==_cities) 
			{
				this.Close();
				
			} 
			else 
			{
				foreach(object city in _cities) 
				{
					departCityCombo.Items.Add(city);
					arriveCityCombo.Items.Add(city);
				}
			}

			// Determine if user is authorized for giving discount
			// Rule: [R:Manager]
			btnDiscount.Visible = SecurityHelper.Authorized(AuthRule.Discount);
			// Determine if user is authorized for booking ticket
			// Rule: [R:Manager OR R:Agent]
			btnBooking.Visible = SecurityHelper.Authorized(AuthRule.Booking);
		}

		#region renderCityCombo not used
//		private void renderCityCombo()
//		{
//			// If cities is null at this point, we had an error - close the form
//			if (null==_cities) 
//			{
//				this.Close();
//				
//			} 
//			else 
//			{
//				if (this._pre_Cities != this._cities)
//				{
//					departCityCombo.Items.Clear();
//					arriveCityCombo.Items.Clear();
//					foreach(object city in _cities) 
//					{
//						departCityCombo.Items.Add(city);
//						arriveCityCombo.Items.Add(city);
//					}
//				}
//			}
//		}
#endregion

		private void btnDiscount_Click(object sender, System.EventArgs e)
		{
			this.Message = "";

			quoteTextBox.ReadOnly = false;
			quoteTextBox.Focus();
		}

		private void btnBooking_Click(object sender, System.EventArgs e)
		{
			// TODO: Booking business logic here

			this.Message = "Booking successfully.";

			//Just log this operation
			LogEntry log = new LogEntry();
			log.Category = Category.Trace;
			log.Priority = Priority.Normal;
			log.Message = string.Format("Operator:[{0}] booked a ticket for...", SecurityHelper.UserCredential.Name);
			Logger.Write(log);
		}

	}
}

